@@ -351,6 +351,7 @@ class Profiles extends SiteController
 		{
 			$sortFound = true;
 		}
+		$filters['sqlsort'] = $filters['sort'];
 
 		// Process incoming filters
 		foreach ($q as $key => $val)
@@ -396,9 +397,10 @@ class Profiles extends SiteController
 					continue;
 				}
 
-				// Multi-value field (radios, checkboxes)
+				// Multi-value field (checkboxes)
 				if (is_array($val['value']))
 				{
+					$val['human_value'] = array();
 					foreach ($val['value'] as $value)
 					{
 						$multi = $val;
@@ -408,10 +410,12 @@ class Profiles extends SiteController
 						{
 							if ($option->get('value') == $value)
 							{
-								$multi['human_value'] = $option->get('label');
+								//$multi['human_value'] = $option->get('label');
+								$val['human_value'][] = $option->get('label');
+								break;
 							}
 						}
-						$filters['q'][] = $multi;
+						//$filters['q'][] = $multi;
 					}
 				}
 				// Single-value field (select list)
@@ -428,7 +432,7 @@ class Profiles extends SiteController
 			}
 
 			// No associated profile field was found
-			if (!isset($val['human_field']) || is_array($val['value']))
+			if (!isset($val['human_field']))// || is_array($val['value']))
 			{
 				continue;
 			}
@@ -572,7 +576,7 @@ class Profiles extends SiteController
 
 				if ($filters['sort'] == $q['field'])
 				{
-					$filters['sort'] = 't' . $i . '.profile_value';
+					$filters['sqlsort'] = 't' . $i . '.profile_value';
 					$sortFound = true;
 				}
 
@@ -586,13 +590,13 @@ class Profiles extends SiteController
 		if (!$sortFound)
 		{
 			$entries->joinRaw($b . ' AS t' . $i, 't' . $i . '.user_id=' . $a . '.id AND t' . $i . '.profile_key=' . $db->quote($filters['sort']), 'inner');
-			$filters['sort'] = 't' . $i . '.profile_value';
+			$filters['sqlsort'] = 't' . $i . '.profile_value';
 		}
 
 		$entries->whereIn($a . '.access', User::getAuthorisedViewLevels());
 
 		$rows = $entries
-			->order($filters['sort'], $filters['sort_Dir'])
+			->order($filters['sqlsort'], $filters['sort_Dir'])
 			->paginated('limitstart', 'limit')
 			->rows();
 
